@@ -15,7 +15,8 @@ missing_types = {int:  np.inf, float: np.inf, str: '<MISSING>', type(None): np.i
 convert_types = {int:  float, float: float, str: str, type(None): float, None: float, bool: float,
                  datetime: lambda x: datetime(x.year, x.month, x.day, x.hour, x.minute, x.second),
                  list: list, tuple: tuple, np.ndarray: np.ndarray, pd.DataFrame: pd.DataFrame, pd.Series: pd.Series,
-                 dict: dict, Table: Table}
+                 dict: dict, Table: Table,
+                 np.int64: int, np.float64: float, np.float32: float, np.int32:int}
 
 def is_null(x):
     try:
@@ -60,6 +61,10 @@ def _convert_datatypes(x, nan2missing=True, none2missing=True, surrounding_type=
             pass
     if surrounding_type is not None:
         return convert_types[surrounding_type](x)
+    for from_type, to_type in convert_types.items():
+        if from_type is not None:
+            if isinstance(x, from_type):
+                x = to_type(x)
     return x
 
 
